/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_BAtMbQMi);
  numBytes += sLine_init(&sLine_XmVcqxbq);
  numBytes += sLine_init(&sLine_1cPIjekD);
  numBytes += sLine_init(&sLine_yUnli8pc);
  numBytes += sLine_init(&sLine_HaLuVI0U);
  numBytes += sBiquad_init(&sBiquad_s_3idbMofC);
  numBytes += sLine_init(&sLine_uOptjXkc);
  numBytes += sLine_init(&sLine_dX8PqkGq);
  numBytes += sLine_init(&sLine_7GAMG7ym);
  numBytes += sLine_init(&sLine_LCKD4qD0);
  numBytes += sBiquad_init(&sBiquad_s_3I9JdT26);
  numBytes += sLine_init(&sLine_M2Ks7NV4);
  numBytes += sLine_init(&sLine_TuM1ID7T);
  numBytes += sLine_init(&sLine_FTJyxfzP);
  numBytes += sLine_init(&sLine_yZN9i7Fx);
  numBytes += sLine_init(&sLine_yy79Plzu);
  numBytes += sBiquad_init(&sBiquad_s_ShsqzL1g);
  numBytes += sLine_init(&sLine_XO94InUB);
  numBytes += sLine_init(&sLine_IwnT8osJ);
  numBytes += sLine_init(&sLine_1tSHUBpq);
  numBytes += sLine_init(&sLine_Y4Bs0vJL);
  numBytes += sLine_init(&sLine_6kJ4HPIP);
  numBytes += sBiquad_init(&sBiquad_s_8xu7kkeb);
  numBytes += sLine_init(&sLine_HV96rVHr);
  numBytes += sLine_init(&sLine_RXANE67b);
  numBytes += sLine_init(&sLine_5MNSbdeg);
  numBytes += sLine_init(&sLine_pzCT4hjY);
  numBytes += sBiquad_init(&sBiquad_s_PqLZclDg);
  numBytes += sLine_init(&sLine_Jf0rbMWq);
  numBytes += sLine_init(&sLine_3fEsx5qr);
  numBytes += sLine_init(&sLine_SiHZ7RQP);
  numBytes += sLine_init(&sLine_4fsVbQVO);
  numBytes += sLine_init(&sLine_Dw8s1xP8);
  numBytes += sBiquad_init(&sBiquad_s_ucWm9oMp);
  numBytes += sLine_init(&sLine_MsL9J8su);
  numBytes += sPhasor_k_init(&sPhasor_9aJVyb0R, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_JgQJaJX7);
  numBytes += sRPole_init(&sRPole_SpTEwTHH);
  numBytes += sRPole_init(&sRPole_XVLLIf03);
  numBytes += sTabhead_init(&sTabhead_DmxnMotw, &hTable_XemrnLTp);
  numBytes += sTabread_init(&sTabread_78BPzzwn, &hTable_XemrnLTp, false);
  numBytes += sTabread_init(&sTabread_DSTo8ssZ, &hTable_XemrnLTp, false);
  numBytes += sLine_init(&sLine_jWUo5u90);
  numBytes += sTabhead_init(&sTabhead_FPq95wLU, &hTable_2lX5gqRc);
  numBytes += sTabread_init(&sTabread_Id7Hs0bn, &hTable_2lX5gqRc, false);
  numBytes += sTabread_init(&sTabread_qQAHg8JW, &hTable_2lX5gqRc, false);
  numBytes += sLine_init(&sLine_D02bjvEp);
  numBytes += sTabwrite_init(&sTabwrite_XqvP4pYX, &hTable_2lX5gqRc);
  numBytes += sTabwrite_init(&sTabwrite_KT1J7g8Y, &hTable_XemrnLTp);
  numBytes += sLine_init(&sLine_nEFnEVxG);
  numBytes += sPhasor_k_init(&sPhasor_P1aYn4C3, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_GNLqYMxw);
  numBytes += sRPole_init(&sRPole_kTYAFi6O);
  numBytes += sRPole_init(&sRPole_Q2fufyrU);
  numBytes += sTabhead_init(&sTabhead_rgGZKacQ, &hTable_NzyXuNHt);
  numBytes += sTabread_init(&sTabread_nVhMEuJA, &hTable_NzyXuNHt, false);
  numBytes += sTabread_init(&sTabread_KOT3L61h, &hTable_NzyXuNHt, false);
  numBytes += sLine_init(&sLine_zLll0frz);
  numBytes += sTabhead_init(&sTabhead_78f8vuef, &hTable_uAvbyeOZ);
  numBytes += sTabread_init(&sTabread_xkhaP8jN, &hTable_uAvbyeOZ, false);
  numBytes += sTabread_init(&sTabread_PYEc1sBx, &hTable_uAvbyeOZ, false);
  numBytes += sLine_init(&sLine_N4Y2cMiR);
  numBytes += sTabwrite_init(&sTabwrite_YYHhZwXI, &hTable_uAvbyeOZ);
  numBytes += sTabwrite_init(&sTabwrite_LocFsqbM, &hTable_NzyXuNHt);
  numBytes += sLine_init(&sLine_5L0M5YbT);
  numBytes += sPhasor_k_init(&sPhasor_b1V2X8lq, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_QSvHzqnz);
  numBytes += sRPole_init(&sRPole_wIopbpih);
  numBytes += sRPole_init(&sRPole_nGRP2xaA);
  numBytes += sTabhead_init(&sTabhead_aZ4T8giN, &hTable_bxHFxKUP);
  numBytes += sTabread_init(&sTabread_f2KQExVG, &hTable_bxHFxKUP, false);
  numBytes += sTabread_init(&sTabread_kugqhPjT, &hTable_bxHFxKUP, false);
  numBytes += sLine_init(&sLine_ImUKVPac);
  numBytes += sTabhead_init(&sTabhead_lpMBpO95, &hTable_ju1CVtu7);
  numBytes += sTabread_init(&sTabread_2MlOMaOQ, &hTable_ju1CVtu7, false);
  numBytes += sTabread_init(&sTabread_yTBl08gp, &hTable_ju1CVtu7, false);
  numBytes += sLine_init(&sLine_K0iaxXYP);
  numBytes += sTabwrite_init(&sTabwrite_FEytsZ1V, &hTable_ju1CVtu7);
  numBytes += sTabwrite_init(&sTabwrite_g5LYvN3q, &hTable_bxHFxKUP);
  numBytes += cVar_init_f(&cVar_C3rRUzbP, 0.0f);
  numBytes += cVar_init_f(&cVar_tDJmTRHd, 0.0f);
  numBytes += cVar_init_f(&cVar_GYZpPQcO, 0.0f);
  numBytes += cVar_init_f(&cVar_ZRhC6tje, 0.0f);
  numBytes += cSlice_init(&cSlice_fgGkvvf2, 1, -1);
  numBytes += cVar_init_f(&cVar_M8F2rzko, 1337.0f);
  numBytes += cVar_init_f(&cVar_iP6B7EEd, 0.0f);
  numBytes += cIf_init(&cIf_yrgfgWWc, false);
  numBytes += cIf_init(&cIf_xmKYXXl0, false);
  numBytes += cBinop_init(&cBinop_XK5rCwJS, 0.0f); // __pow
  numBytes += cIf_init(&cIf_qWmHizKF, false);
  numBytes += cBinop_init(&cBinop_A0i0YxMj, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_O3UErqVo, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_q7A3CMOG, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_7XbNmT7w, 0.0f);
  numBytes += cIf_init(&cIf_cudst2vq, false);
  numBytes += cIf_init(&cIf_TEBgpE0u, false);
  numBytes += cBinop_init(&cBinop_JPo2wku2, 0.0f); // __pow
  numBytes += cIf_init(&cIf_zRqKWIzB, false);
  numBytes += cBinop_init(&cBinop_vb3xHIaP, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_SxycJ60n, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_lSQQUmbm, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_v68XBxJt, 0.0f);
  numBytes += cIf_init(&cIf_TfOyy61p, false);
  numBytes += cIf_init(&cIf_BqrbtxuT, false);
  numBytes += cBinop_init(&cBinop_oD5nDl49, 0.0f); // __pow
  numBytes += cIf_init(&cIf_F0xNwWDT, false);
  numBytes += cBinop_init(&cBinop_r7L8Gadr, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_PufXJCYB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8TaeMqZ7, -15.0f); // __eq
  numBytes += cIf_init(&cIf_ZUfNwwoH, false);
  numBytes += cSlice_init(&cSlice_pn7JQbwJ, 1, -1);
  numBytes += cVar_init_f(&cVar_wsFLXy6I, 0.0f);
  numBytes += cSlice_init(&cSlice_6jv87wJh, 1, -1);
  numBytes += cVar_init_f(&cVar_a39QNV78, 0.0f);
  numBytes += cSlice_init(&cSlice_SsASWshR, 1, -1);
  numBytes += cVar_init_f(&cVar_FAzoYSKS, 0.0f);
  numBytes += cSlice_init(&cSlice_U6ZMV8Qv, 1, -1);
  numBytes += cVar_init_f(&cVar_bdxy6kBE, 0.313f);
  numBytes += cBinop_init(&cBinop_x2wsnmtk, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_FimBRDNq, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_UwQMVkOt, 0.0f);
  numBytes += cVar_init_f(&cVar_0sZFIhVp, 1337.0f);
  numBytes += cVar_init_f(&cVar_Z3DbkY2d, 0.3f);
  numBytes += cBinop_init(&cBinop_5EnENux9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ae3jFBLk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PdAVJMj2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MSmVVtfG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qs185HFo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fMDd7uxH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0FgYMPix, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_OVfh7X29, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_KBbi8HAP, 0.0f);
  numBytes += cVar_init_f(&cVar_9A1Gx6jV, 1337.0f);
  numBytes += cVar_init_f(&cVar_Enmz2FAq, 0.313f);
  numBytes += cBinop_init(&cBinop_vjRoZxnY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9KDKacHc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3RbBFM5P, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KbDR7YO1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fwAHsMET, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Hlmm6x4a, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_FSlrAdbY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_GWK8OLEM, 0.0f);
  numBytes += cVar_init_f(&cVar_5fUZoFyy, 1037.0f);
  numBytes += cVar_init_f(&cVar_4eQfbEEm, 0.4f);
  numBytes += cBinop_init(&cBinop_VTJpjnAh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E8LBF9wm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_X9vzvRmv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_30vTk93l, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uHuTZIoF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1YFcXVk4, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_W8twbb8y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_r0Nn8xur, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aIYBhML3, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_00BPFykt, 1, -1);
  numBytes += cVar_init_f(&cVar_W5JzeQlN, 1337.0f);
  numBytes += cVar_init_f(&cVar_ocKt3dRl, 0.0f);
  numBytes += cIf_init(&cIf_3yMl9f6K, false);
  numBytes += cIf_init(&cIf_JPfu1S9Z, false);
  numBytes += cBinop_init(&cBinop_JVhyol5d, 0.0f); // __pow
  numBytes += cIf_init(&cIf_s4mNB8mV, false);
  numBytes += cBinop_init(&cBinop_7sngaiPP, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_YUItkRop, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_MQj0Hn18, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_EC1bJc73, 0.0f);
  numBytes += cIf_init(&cIf_9iWNMcKR, false);
  numBytes += cIf_init(&cIf_Zx9GJ8Or, false);
  numBytes += cBinop_init(&cBinop_ut35QbFx, 0.0f); // __pow
  numBytes += cIf_init(&cIf_TrBX5jeQ, false);
  numBytes += cBinop_init(&cBinop_m8X7J5jp, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_XkABplzS, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_13h0OGUL, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_6YIJu8sL, 0.0f);
  numBytes += cIf_init(&cIf_qQhRmKHB, false);
  numBytes += cIf_init(&cIf_LY8HPMSa, false);
  numBytes += cBinop_init(&cBinop_soMAcZla, 0.0f); // __pow
  numBytes += cIf_init(&cIf_8hxW2RHk, false);
  numBytes += cBinop_init(&cBinop_5ZXsv2LC, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_fAlFhcDA, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_euKkhcCD, -15.0f); // __eq
  numBytes += cIf_init(&cIf_mMRNk6Cb, false);
  numBytes += cSlice_init(&cSlice_YgDwd5Tf, 1, -1);
  numBytes += cVar_init_f(&cVar_VeFGc12u, 0.0f);
  numBytes += cSlice_init(&cSlice_F7O7JVxl, 1, -1);
  numBytes += cVar_init_f(&cVar_JevX9dny, 0.0f);
  numBytes += cSlice_init(&cSlice_JScPSLlB, 1, -1);
  numBytes += cVar_init_f(&cVar_kTg72Zao, 0.0f);
  numBytes += cSlice_init(&cSlice_iPt14Z4R, 1, -1);
  numBytes += cVar_init_f(&cVar_OvCi3CiE, 0.313f);
  numBytes += cBinop_init(&cBinop_4mAevPRk, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_mTkhvvQo, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_EninVmYG, 0.0f);
  numBytes += cVar_init_f(&cVar_pMv84C39, 1337.0f);
  numBytes += cVar_init_f(&cVar_kQYzCoVM, 0.3f);
  numBytes += cBinop_init(&cBinop_wbA9ZN5B, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vSmvCJUw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dR7vV5YF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MEQBFP0o, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qI53wpyx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UNa40Xfm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qZilGeaV, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_r73uyglQ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xvSnNPUb, 0.0f);
  numBytes += cVar_init_f(&cVar_ExNToFOG, 1337.0f);
  numBytes += cVar_init_f(&cVar_v475UwPj, 0.313f);
  numBytes += cBinop_init(&cBinop_zVNWAwvP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_h40jDz6N, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LIe8lwSr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UzXJC0fv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qpsgnlye, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nFBlLGck, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_scOtA45K, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_maathZDI, 0.0f);
  numBytes += cVar_init_f(&cVar_HTCoE6ss, 1037.0f);
  numBytes += cVar_init_f(&cVar_mxdB2esA, 0.4f);
  numBytes += cBinop_init(&cBinop_iYg94QOb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4fDjuA68, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OGJi3UMB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QJEtxVyZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Xsk4oTad, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_67srapFr, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_bbmbK63f, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UEmzHYXP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bY5BKyAj, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vF5gt0E4, 5705.6f);
  numBytes += cVar_init_f(&cVar_ajvubj2a, 313.3f);
  numBytes += cBinop_init(&cBinop_8c6mLDaD, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_C00vGkk1, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_kQTbMsw8, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_thtU6vNH, 0.0f);
  numBytes += cVar_init_f(&cVar_LnZO4cei, 0.0f);
  numBytes += cVar_init_f(&cVar_Qy8b6AUR, 0.0f);
  numBytes += cVar_init_f(&cVar_r3bV7kSu, 0.0f);
  numBytes += cVar_init_f(&cVar_Zz6R2HJx, 0.0f);
  numBytes += cVar_init_f(&cVar_9y3xMg3g, 0.0f);
  numBytes += cVar_init_f(&cVar_3q9krZxu, 0.0f);
  numBytes += cVar_init_f(&cVar_dUAa4X63, 0.0f);
  numBytes += cVar_init_f(&cVar_1nuwXCvF, 0.0f);
  numBytes += cVar_init_f(&cVar_5ot0bJ9F, 0.0f);
  numBytes += cVar_init_f(&cVar_R5hucfn5, 0.0f);
  numBytes += cVar_init_f(&cVar_m4c2ASGg, 0.0f);
  numBytes += cVar_init_s(&cVar_pukDFlFG, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_jUBqAtow, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fOHhIhv3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WAwhTfVj, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_cmaAwCsW, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_SLgWPlA8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KEv0O5Lx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0QkO7DvX, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_3sdr9e7l, 0.0f);
  numBytes += cDelay_init(this, &cDelay_TZau7kl7, 0.0f);
  numBytes += hTable_init(&hTable_2lX5gqRc, 256);
  numBytes += cDelay_init(this, &cDelay_YPyhatBL, 0.0f);
  numBytes += cDelay_init(this, &cDelay_iGkqxYCg, 0.0f);
  numBytes += hTable_init(&hTable_XemrnLTp, 256);
  numBytes += cVar_init_f(&cVar_No0kPkwV, 14.0f);
  numBytes += cBinop_init(&cBinop_dEGLT7iH, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_wFn0n7gK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qRuryY0w, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_QhQ0KyZY, 14.0f);
  numBytes += cBinop_init(&cBinop_MCWzvUKy, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_km37HkCW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_n77kZjr9, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_EeKnXP0q, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_M28oCU4g, 1, -1);
  numBytes += cVar_init_f(&cVar_DMDnpgiQ, 0.2f);
  numBytes += cSlice_init(&cSlice_2BkJFzPQ, 1, -1);
  numBytes += cVar_init_f(&cVar_MQ7dbIdB, 0.0f);
  numBytes += cSlice_init(&cSlice_PD85QxnJ, 1, -1);
  numBytes += cVar_init_f(&cVar_Qts9iSEK, 2.0f);
  numBytes += cSlice_init(&cSlice_b24apefb, 1, -1);
  numBytes += cVar_init_f(&cVar_PGZAgHBV, 0.5f);
  numBytes += cVar_init_s(&cVar_o9eBPytx, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_SSDOP5q4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YXdOUsaG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6fd0OvF4, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_2JC6cpn5, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_xE1cvTNp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0WIpCIEm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vwYubBaA, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_Xuy6Pheq, 0.0f);
  numBytes += cDelay_init(this, &cDelay_aOTvSI5C, 0.0f);
  numBytes += hTable_init(&hTable_uAvbyeOZ, 256);
  numBytes += cDelay_init(this, &cDelay_xRDC0y0q, 0.0f);
  numBytes += cDelay_init(this, &cDelay_J3i8wwN6, 0.0f);
  numBytes += hTable_init(&hTable_NzyXuNHt, 256);
  numBytes += cVar_init_f(&cVar_BRNkRMrn, 14.0f);
  numBytes += cBinop_init(&cBinop_r9Zpr0Ct, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_FAHzwACk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hbCpFVE3, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_N9mGXkbV, 14.0f);
  numBytes += cBinop_init(&cBinop_QClPrFpq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_QwEwhZFr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_winWvuh6, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_sSI9gAUF, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_XzwGtDnM, 1, -1);
  numBytes += cVar_init_f(&cVar_gEqQ2jRO, 0.2f);
  numBytes += cSlice_init(&cSlice_Qpec9Fli, 1, -1);
  numBytes += cVar_init_f(&cVar_v7wtpgCX, 0.0f);
  numBytes += cSlice_init(&cSlice_tjryGecy, 1, -1);
  numBytes += cVar_init_f(&cVar_ifwx1cj4, 2.0f);
  numBytes += cSlice_init(&cSlice_WE6MH1o5, 1, -1);
  numBytes += cVar_init_f(&cVar_zET3sh3f, 0.5f);
  numBytes += cVar_init_s(&cVar_90BBDfMX, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_QsekSImd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_POEhNnca, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dg7ARkQV, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_mAD5lq1j, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_jNHka5Lc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lfAfd0n9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MW4sYOOY, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_RR8AdrYI, 0.0f);
  numBytes += cDelay_init(this, &cDelay_y1x8M6GC, 0.0f);
  numBytes += hTable_init(&hTable_ju1CVtu7, 256);
  numBytes += cDelay_init(this, &cDelay_u7xhMnrf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_AgyerBrJ, 0.0f);
  numBytes += hTable_init(&hTable_bxHFxKUP, 256);
  numBytes += cVar_init_f(&cVar_BchcgEPk, 14.0f);
  numBytes += cBinop_init(&cBinop_GpRZ9yV6, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_P5HBwiX6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Wmggisut, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1MSsQsFV, 14.0f);
  numBytes += cBinop_init(&cBinop_ptelfLVi, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_TfgoQ8dY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0DjG9aqW, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_0mWs9mIa, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_4IOnxRi0, 1, -1);
  numBytes += cVar_init_f(&cVar_lGPtcbbU, 0.2f);
  numBytes += cSlice_init(&cSlice_H6zjOTqw, 1, -1);
  numBytes += cVar_init_f(&cVar_1REYUMkQ, 0.0f);
  numBytes += cSlice_init(&cSlice_MtRP13VJ, 1, -1);
  numBytes += cVar_init_f(&cVar_1EWY9FoD, 2.0f);
  numBytes += cSlice_init(&cSlice_Ose4d9Zx, 1, -1);
  numBytes += cVar_init_f(&cVar_E1AFvY0C, 0.5f);
  numBytes += sVarf_init(&sVarf_qMGfJFv2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ov8qt39V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_b7gV5hyy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yPkzdcTI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cGZA91Tj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_O78fgHGi, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_2lX5gqRc);
  hTable_free(&hTable_XemrnLTp);
  hTable_free(&hTable_uAvbyeOZ);
  hTable_free(&hTable_NzyXuNHt);
  hTable_free(&hTable_ju1CVtu7);
  hTable_free(&hTable_bxHFxKUP);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_2lX5gqRc; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_XemrnLTp; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_uAvbyeOZ; // del-1397-flanger-r
    case 0x578173CB: return &hTable_NzyXuNHt; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_ju1CVtu7; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_bxHFxKUP; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CBJLpZZC_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S7sJsr7i_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Km6q5nGZ_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GxMGoTbo_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zRsf0x1O_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aQwd4fdU_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Pl86Ug18_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_V7dKYhGh_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_guWj735h_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q56FsVzR_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vhCipZcR_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vfbt3mQx_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7aCclhGN_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_16ZjOzdV_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YpObIOYT_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TL51TVQ9_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wtMu8bJV_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xAojO73w_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0JFJh7BK_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JoYfFurI_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ASKSfpp0_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gHuKSG1K_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_43baf0o5_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XSrcxAVi_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9dMpD36X_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GdaHn77H_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Mc6BovkE_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vMmks9w8_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ja2DyNmb_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ALguVv42_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4PcKS3n1_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hTNCnozZ_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QyA0HGsX_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q93iLKsV_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RZgUYbzt_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6tLJG1p0_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A3Ya6c3t_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ApTsXFi0_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VqmEAq5y_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MAbXpYWb_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gXJU4R97_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dHQeoMVS_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HO7JmCI7_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wKNLmsU2_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LUz7pmwr_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_70M8885L_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m7UtTthi_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kp6GbQDK_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wRdmzufk_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_i2Q7REZu_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O4o7he7f_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FcYBx1AJ_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gxQeOPQk_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sOcaS8w1_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5rBPoANg_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UVhWR9MI_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cZQCHkza_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_C3rRUzbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3SqHMEdO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_tDJmTRHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aMb1iQB0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_GYZpPQcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hYY0oCEn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ZRhC6tje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s3nkwdWN_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T2MsPTxO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZkE5yE7e_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LJoSUS07_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_EjHwgONy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fgGkvvf2, 0, m, &cSlice_fgGkvvf2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GsmAPVg7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_fgGkvvf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HR6N77iQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HR6N77iQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_M8F2rzko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HR6N77iQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_HR6N77iQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0JFJh7BK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_iP6B7EEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_48KelF2h_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_yrgfgWWc, 0, m, &cIf_yrgfgWWc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_yrgfgWWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qG2Vu6p7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_xmKYXXl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_4sPV539C_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_qUjrEyDq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_ueNDuA7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XK5rCwJS, HV_BINOP_POW, 0, m, &cBinop_XK5rCwJS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XK5rCwJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qWmHizKF, 0, m, &cIf_qWmHizKF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GJfC3DJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_AYri46Yy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_E0ucItll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_EtPPckoU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NRYT59An_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xmKYXXl0, 0, m, &cIf_xmKYXXl0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EtPPckoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xmKYXXl0, 1, m, &cIf_xmKYXXl0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qUjrEyDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GJfC3DJR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4sPV539C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_qWmHizKF, 0, m, &cIf_qWmHizKF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AYri46Yy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XK5rCwJS, HV_BINOP_POW, 1, m, &cBinop_XK5rCwJS_sendMessage);
  cMsg_ueNDuA7f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_qWmHizKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_W8twbb8y, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_48KelF2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yrgfgWWc, 1, m, &cIf_yrgfgWWc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qG2Vu6p7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O3UErqVo, HV_BINOP_GREATER_THAN, 1, m, &cBinop_O3UErqVo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_q7A3CMOG, HV_BINOP_EQ, 1, m, &cBinop_q7A3CMOG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_SulCKCFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_A0i0YxMj, HV_BINOP_ADD, 0, m, &cBinop_A0i0YxMj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_A0i0YxMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E0ucItll_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NRYT59An_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_O3UErqVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qWmHizKF, 1, m, &cIf_qWmHizKF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q7A3CMOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xujLPwpd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_xujLPwpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_W8twbb8y, m);
}

void Heavy_WSTD_FL3NGR::cCast_IPpzxdge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SulCKCFw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_dCQhVIOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A0i0YxMj, HV_BINOP_ADD, 1, m, &cBinop_A0i0YxMj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O3UErqVo, HV_BINOP_GREATER_THAN, 0, m, &cBinop_O3UErqVo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_q7A3CMOG, HV_BINOP_EQ, 0, m, &cBinop_q7A3CMOG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_M2ZvC0SP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iP6B7EEd, 0, m, &cVar_iP6B7EEd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_7XbNmT7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fCvnYr10_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_cudst2vq, 0, m, &cIf_cudst2vq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_cudst2vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0ehPM8dj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_TEBgpE0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Xi8amegG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_BYrcpNmp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_Y0NhIbIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPo2wku2, HV_BINOP_POW, 0, m, &cBinop_JPo2wku2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JPo2wku2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zRqKWIzB, 0, m, &cIf_zRqKWIzB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i1S57iHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vVoXXN51_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ymHvqQDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TEBgpE0u, 0, m, &cIf_TEBgpE0u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rSnQ50Ms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vtvIj7b2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vtvIj7b2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TEBgpE0u, 1, m, &cIf_TEBgpE0u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BYrcpNmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_i1S57iHc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Xi8amegG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_zRqKWIzB, 0, m, &cIf_zRqKWIzB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vVoXXN51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPo2wku2, HV_BINOP_POW, 1, m, &cBinop_JPo2wku2_sendMessage);
  cMsg_Y0NhIbIq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_zRqKWIzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_o7adSEON_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1ZKDIJKU_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_UXTayBig_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_fCvnYr10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cudst2vq, 1, m, &cIf_cudst2vq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0ehPM8dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SxycJ60n, HV_BINOP_GREATER_THAN, 1, m, &cBinop_SxycJ60n_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lSQQUmbm, HV_BINOP_EQ, 1, m, &cBinop_lSQQUmbm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_RiWiLq5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vb3xHIaP, HV_BINOP_ADD, 0, m, &cBinop_vb3xHIaP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vb3xHIaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rSnQ50Ms_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ymHvqQDD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SxycJ60n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zRqKWIzB, 1, m, &cIf_zRqKWIzB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lSQQUmbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cF7mn0PL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_cF7mn0PL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_o7adSEON_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1ZKDIJKU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_UXTayBig_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fRei54X4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7XbNmT7w, 0, m, &cVar_7XbNmT7w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2CcbO7VA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RiWiLq5C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_N0MUchBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vb3xHIaP, HV_BINOP_ADD, 1, m, &cBinop_vb3xHIaP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SxycJ60n, HV_BINOP_GREATER_THAN, 0, m, &cBinop_SxycJ60n_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lSQQUmbm, HV_BINOP_EQ, 0, m, &cBinop_lSQQUmbm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_v68XBxJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0pfMyAZY_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_TfOyy61p, 0, m, &cIf_TfOyy61p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_TfOyy61p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TikfDwwv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_BqrbtxuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_sQkn7ooW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_QfWEQT1I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_eq1anzMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oD5nDl49, HV_BINOP_POW, 0, m, &cBinop_oD5nDl49_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oD5nDl49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F0xNwWDT, 0, m, &cIf_F0xNwWDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jXqmW7I5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_0gQCCvYe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wSCGBhv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BqrbtxuT, 0, m, &cIf_BqrbtxuT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bxvby7Fa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_z3wuZB55_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z3wuZB55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BqrbtxuT, 1, m, &cIf_BqrbtxuT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QfWEQT1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_jXqmW7I5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sQkn7ooW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_F0xNwWDT, 0, m, &cIf_F0xNwWDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0gQCCvYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oD5nDl49, HV_BINOP_POW, 1, m, &cBinop_oD5nDl49_sendMessage);
  cMsg_eq1anzMX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_F0xNwWDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_aIYBhML3, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_0pfMyAZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TfOyy61p, 1, m, &cIf_TfOyy61p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TikfDwwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PufXJCYB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_PufXJCYB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8TaeMqZ7, HV_BINOP_EQ, 1, m, &cBinop_8TaeMqZ7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bFpG5B2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_r7L8Gadr, HV_BINOP_ADD, 0, m, &cBinop_r7L8Gadr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_r7L8Gadr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bxvby7Fa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wSCGBhv5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PufXJCYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F0xNwWDT, 1, m, &cIf_F0xNwWDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8TaeMqZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Poh4nZLK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Poh4nZLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_aIYBhML3, m);
}

void Heavy_WSTD_FL3NGR::cCast_tUAH3m4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v68XBxJt, 0, m, &cVar_v68XBxJt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_J2d65VsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bFpG5B2Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_uBWKPwoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r7L8Gadr, HV_BINOP_ADD, 1, m, &cBinop_r7L8Gadr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PufXJCYB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_PufXJCYB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8TaeMqZ7, HV_BINOP_EQ, 0, m, &cBinop_8TaeMqZ7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_ZUfNwwoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_r0Nn8xur, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_xbZ9zjRp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pn7JQbwJ, 0, m, &cSlice_pn7JQbwJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WvCIDeg9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_pn7JQbwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EvR8ugdT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EvR8ugdT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_wsFLXy6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EvR8ugdT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_EvR8ugdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wtMu8bJV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_WvCIDeg9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6jv87wJh, 0, m, &cSlice_6jv87wJh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EjHwgONy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_6jv87wJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ynfppcVl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ynfppcVl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_a39QNV78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ynfppcVl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ynfppcVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ASKSfpp0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_GsmAPVg7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SsASWshR, 0, m, &cSlice_SsASWshR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tAw7n9oV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_SsASWshR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Zt7m2Ma8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Zt7m2Ma8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_FAzoYSKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Zt7m2Ma8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Zt7m2Ma8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xAojO73w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_tAw7n9oV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_U6ZMV8Qv, 0, m, &cSlice_U6ZMV8Qv_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_U6ZMV8Qv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_22j6bI7z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_22j6bI7z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_bdxy6kBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_22j6bI7z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_22j6bI7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JoYfFurI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_TU4kdspE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BAtMbQMi, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_P2fvmhEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XmVcqxbq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_I0G5Q1Qv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1cPIjekD, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_KaVnl9kE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yUnli8pc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_KCM9Gby8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HaLuVI0U, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_wRyTMHl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zOmoadKz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_zOmoadKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x2wsnmtk, HV_BINOP_DIVIDE, 1, m, &cBinop_x2wsnmtk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LalP0Ehs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_NeP7WsHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_kGgg72uY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sh1SDFqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_NeP7WsHt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kGgg72uY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x2wsnmtk, HV_BINOP_DIVIDE, 0, m, &cBinop_x2wsnmtk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LalP0Ehs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sh1SDFqz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_x2wsnmtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FimBRDNq, HV_BINOP_MULTIPLY, 1, m, &cBinop_FimBRDNq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FimBRDNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WEiAUcMo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tS1MRpdj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_78eBTfg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XjNnGwFL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_9HungbEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_x6NSzwP9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QLRPRjux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_TVIE8fuK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TVIE8fuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FimBRDNq, HV_BINOP_MULTIPLY, 0, m, &cBinop_FimBRDNq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BVNQ515g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_kUquY8Z1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kUquY8Z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_00OPIFEO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MYLBcbZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UwQMVkOt, 1, m, &cVar_UwQMVkOt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_UwQMVkOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_seVAIkXO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ObxaMQHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ae3jFBLk, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ae3jFBLk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_82fwS8Ke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ObxaMQHT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TT6lZCcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mSAdDqus_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mSAdDqus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PdAVJMj2, HV_BINOP_MULTIPLY, 1, m, &cBinop_PdAVJMj2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z1dHz3Z0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MSmVVtfG, HV_BINOP_MULTIPLY, 1, m, &cBinop_MSmVVtfG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_U7IoV9uL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_z1dHz3Z0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_U0Xe7z0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qs185HFo, HV_BINOP_MULTIPLY, 1, m, &cBinop_qs185HFo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_65Lwr9rg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_v9mv8nBD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_v9mv8nBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fMDd7uxH, HV_BINOP_MULTIPLY, 1, m, &cBinop_fMDd7uxH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_0sZFIhVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xpB4ZPqP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_QLRPRjux_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rsgKBJdq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Z3DbkY2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_BVNQ515g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WEiAUcMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_78eBTfg5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tS1MRpdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_9HungbEg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_XjNnGwFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XSrcxAVi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_x6NSzwP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_43baf0o5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ByZPghCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gHuKSG1K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_00OPIFEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lUElF2Es_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lUElF2Es_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5EnENux9, HV_BINOP_MULTIPLY, 1, m, &cBinop_5EnENux9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5EnENux9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FqbD7ygc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FqbD7ygc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ByZPghCs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_seVAIkXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WKafMB36_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WKafMB36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9ddAIDNT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mrqnqK5B_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kMPyHYya_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Uj4OfVg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tWXG3EXY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uGWouwmH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ae3jFBLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TU4kdspE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_PdAVJMj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P2fvmhEg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MSmVVtfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I0G5Q1Qv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qs185HFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KaVnl9kE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fMDd7uxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KCM9Gby8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_DR5ZxRKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0sZFIhVp, 0, m, &cVar_0sZFIhVp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8Kw4G1Hs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z3DbkY2d, 1, m, &cVar_Z3DbkY2d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tWXG3EXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PdAVJMj2, HV_BINOP_MULTIPLY, 0, m, &cBinop_PdAVJMj2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9ddAIDNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_uGWouwmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ae3jFBLk, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ae3jFBLk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9Uj4OfVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MSmVVtfG, HV_BINOP_MULTIPLY, 0, m, &cBinop_MSmVVtfG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kMPyHYya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qs185HFo, HV_BINOP_MULTIPLY, 0, m, &cBinop_qs185HFo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mrqnqK5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fMDd7uxH, HV_BINOP_MULTIPLY, 0, m, &cBinop_fMDd7uxH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xpB4ZPqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z3DbkY2d, 0, m, &cVar_Z3DbkY2d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rsgKBJdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UwQMVkOt, 0, m, &cVar_UwQMVkOt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YqAy34oY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uOptjXkc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_kXoaflOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dX8PqkGq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_WtYkxoNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7GAMG7ym, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_2JRw8hKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LCKD4qD0, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xorwMsP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Un1en5wn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Un1en5wn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0FgYMPix, HV_BINOP_DIVIDE, 1, m, &cBinop_0FgYMPix_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZYE2Hp5u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_s6iQ07Uc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_m6e4qkBt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xdCDa5ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_s6iQ07Uc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_m6e4qkBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0FgYMPix, HV_BINOP_DIVIDE, 0, m, &cBinop_0FgYMPix_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZYE2Hp5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xdCDa5ay_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0FgYMPix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OVfh7X29, HV_BINOP_MULTIPLY, 1, m, &cBinop_OVfh7X29_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OVfh7X29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kT9SEF1S_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HLQo1J5e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_kVioQwm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yIH453As_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_ef82jq5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rdUYWptL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bdeivjSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_pNzHNAd8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pNzHNAd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OVfh7X29, HV_BINOP_MULTIPLY, 0, m, &cBinop_OVfh7X29_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gPWohWqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_zvA7O97D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zvA7O97D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UGae3DNM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_JLuLDTH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3RbBFM5P, HV_BINOP_MULTIPLY, 1, m, &cBinop_3RbBFM5P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mpMpRyEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KBbi8HAP, 1, m, &cVar_KBbi8HAP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1qHlaul8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KbDR7YO1, HV_BINOP_MULTIPLY, 1, m, &cBinop_KbDR7YO1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Pt3SoxX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HKCjGYLD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HKCjGYLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fwAHsMET, HV_BINOP_MULTIPLY, 1, m, &cBinop_fwAHsMET_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_KBbi8HAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jXRUIue8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_9A1Gx6jV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Au2K29ZW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_bdeivjSL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tSo04HKE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Enmz2FAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gPWohWqm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HLQo1J5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ef82jq5y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kT9SEF1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_kVioQwm9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_yIH453As_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Mc6BovkE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_rdUYWptL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GdaHn77H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_npSxy88c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9dMpD36X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_UGae3DNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_u3jZiwF2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_u3jZiwF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vjRoZxnY, HV_BINOP_MULTIPLY, 1, m, &cBinop_vjRoZxnY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vjRoZxnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Zm0XDEba_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Zm0XDEba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_npSxy88c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jXRUIue8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MAG85mNz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MAG85mNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JOq2KOIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sJNuhpBu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TweWXVpb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AfSr1xPl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9KDKacHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YqAy34oY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3RbBFM5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kXoaflOJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KbDR7YO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WtYkxoNg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fwAHsMET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2JRw8hKW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_rjjxRCiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9A1Gx6jV, 0, m, &cVar_9A1Gx6jV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zAnii2F0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Enmz2FAq, 1, m, &cVar_Enmz2FAq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Au2K29ZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Enmz2FAq, 0, m, &cVar_Enmz2FAq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tSo04HKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KBbi8HAP, 0, m, &cVar_KBbi8HAP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TweWXVpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3RbBFM5P, HV_BINOP_MULTIPLY, 0, m, &cBinop_3RbBFM5P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AfSr1xPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9KDKacHc, HV_BINOP_MULTIPLY, 0, m, &cBinop_9KDKacHc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sJNuhpBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KbDR7YO1, HV_BINOP_MULTIPLY, 0, m, &cBinop_KbDR7YO1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JOq2KOIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fwAHsMET, HV_BINOP_MULTIPLY, 0, m, &cBinop_fwAHsMET_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_x8ho82xg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M2Ks7NV4, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8MkuqFbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TuM1ID7T, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_zvCWDkiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FTJyxfzP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MGiGWBFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yZN9i7Fx, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1pw0efZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yy79Plzu, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YK1E7uV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9LzJgOp2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_9LzJgOp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hlmm6x4a, HV_BINOP_DIVIDE, 1, m, &cBinop_Hlmm6x4a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c2wzO2vb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_msbZjeDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_n1q3e7oi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_17ir2Yc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_msbZjeDJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_n1q3e7oi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hlmm6x4a, HV_BINOP_DIVIDE, 0, m, &cBinop_Hlmm6x4a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_c2wzO2vb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_17ir2Yc7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Hlmm6x4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FSlrAdbY, HV_BINOP_MULTIPLY, 1, m, &cBinop_FSlrAdbY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FSlrAdbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gLq4L0J7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tsShOgOs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_dZthQwv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BF7UAVir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_4pe3Dbia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_99zMCxxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6Qo9qOGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_3bidrT1W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3bidrT1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FSlrAdbY, HV_BINOP_MULTIPLY, 0, m, &cBinop_FSlrAdbY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IGkK1Eub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dZ0wvYQO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dZ0wvYQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9gjXkwo6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Aym5273l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E8LBF9wm, HV_BINOP_MULTIPLY, 1, m, &cBinop_E8LBF9wm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ieeqz1pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_E7OFa0dl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_E7OFa0dl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Aym5273l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EFLGKzAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mOxp8dlf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mOxp8dlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X9vzvRmv, HV_BINOP_MULTIPLY, 1, m, &cBinop_X9vzvRmv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qAaesUbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_30vTk93l, HV_BINOP_MULTIPLY, 1, m, &cBinop_30vTk93l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7ZN49EBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rhiOu1Gp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rhiOu1Gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qAaesUbZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2bYwYI7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GWK8OLEM, 1, m, &cVar_GWK8OLEM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cZNpVhgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uHuTZIoF, HV_BINOP_MULTIPLY, 1, m, &cBinop_uHuTZIoF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qxcn52TW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_r4OzGsBb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_r4OzGsBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1YFcXVk4, HV_BINOP_MULTIPLY, 1, m, &cBinop_1YFcXVk4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_GWK8OLEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wTjfRdMD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_5fUZoFyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wxXRY9oz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_6Qo9qOGC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3YPsRKeP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_4eQfbEEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_IGkK1Eub_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tsShOgOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_4pe3Dbia_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gLq4L0J7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_dZthQwv8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_BF7UAVir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ALguVv42_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_99zMCxxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ja2DyNmb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_luyGLjgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vMmks9w8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_9gjXkwo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YdgqK8DO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YdgqK8DO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VTJpjnAh, HV_BINOP_MULTIPLY, 1, m, &cBinop_VTJpjnAh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VTJpjnAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nV3iI2tX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nV3iI2tX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_luyGLjgH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wTjfRdMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8Lq8DqqB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8Lq8DqqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mxp0zFeH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rv1XJ4HY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HtzIkjZN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Uto9gKn0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v5kcHve7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lxIeTCGK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_E8LBF9wm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x8ho82xg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_X9vzvRmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8MkuqFbA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_30vTk93l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zvCWDkiJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uHuTZIoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MGiGWBFY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1YFcXVk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1pw0efZX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_HvtAThra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5fUZoFyy, 0, m, &cVar_5fUZoFyy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xshSocOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4eQfbEEm, 1, m, &cVar_4eQfbEEm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Uto9gKn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_30vTk93l, HV_BINOP_MULTIPLY, 0, m, &cBinop_30vTk93l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Rv1XJ4HY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1YFcXVk4, HV_BINOP_MULTIPLY, 0, m, &cBinop_1YFcXVk4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_v5kcHve7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X9vzvRmv, HV_BINOP_MULTIPLY, 0, m, &cBinop_X9vzvRmv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lxIeTCGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E8LBF9wm, HV_BINOP_MULTIPLY, 0, m, &cBinop_E8LBF9wm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Mxp0zFeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_HtzIkjZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uHuTZIoF, HV_BINOP_MULTIPLY, 0, m, &cBinop_uHuTZIoF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wxXRY9oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4eQfbEEm, 0, m, &cVar_4eQfbEEm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3YPsRKeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GWK8OLEM, 0, m, &cVar_GWK8OLEM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_o7adSEON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZUfNwwoH, 1, m, &cIf_ZUfNwwoH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wZw0M3xx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_r0Nn8xur, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1ZKDIJKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wZw0M3xx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UXTayBig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZUfNwwoH, 0, m, &cIf_ZUfNwwoH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_jKRUdtqv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_00BPFykt, 0, m, &cSlice_00BPFykt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lf5Y70Y0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_00BPFykt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lfF0U9xC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lfF0U9xC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_W5JzeQlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lfF0U9xC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_lfF0U9xC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QyA0HGsX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ocKt3dRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tTIjg154_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_3yMl9f6K, 0, m, &cIf_3yMl9f6K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_3yMl9f6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5dPapbxt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_JPfu1S9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3eMWHtjm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_V6mVqdxS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_kKHVapzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JVhyol5d, HV_BINOP_POW, 0, m, &cBinop_JVhyol5d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JVhyol5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s4mNB8mV, 0, m, &cIf_s4mNB8mV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iH6p1liA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_CjLr1Z8X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_59zvUMyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fB1YpMDI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XSAhZG1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JPfu1S9Z, 0, m, &cIf_JPfu1S9Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fB1YpMDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JPfu1S9Z, 1, m, &cIf_JPfu1S9Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V6mVqdxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_iH6p1liA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3eMWHtjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_s4mNB8mV, 0, m, &cIf_s4mNB8mV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CjLr1Z8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JVhyol5d, HV_BINOP_POW, 1, m, &cBinop_JVhyol5d_sendMessage);
  cMsg_kKHVapzF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_s4mNB8mV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_bbmbK63f, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_tTIjg154_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3yMl9f6K, 1, m, &cIf_3yMl9f6K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5dPapbxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YUItkRop, HV_BINOP_GREATER_THAN, 1, m, &cBinop_YUItkRop_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MQj0Hn18, HV_BINOP_EQ, 1, m, &cBinop_MQj0Hn18_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Z2LzrOPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7sngaiPP, HV_BINOP_ADD, 0, m, &cBinop_7sngaiPP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7sngaiPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_59zvUMyn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XSAhZG1n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YUItkRop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s4mNB8mV, 1, m, &cIf_s4mNB8mV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MQj0Hn18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YihFzGgf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_YihFzGgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bbmbK63f, m);
}

void Heavy_WSTD_FL3NGR::cCast_KoFqa2Cd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7sngaiPP, HV_BINOP_ADD, 1, m, &cBinop_7sngaiPP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YUItkRop, HV_BINOP_GREATER_THAN, 0, m, &cBinop_YUItkRop_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MQj0Hn18, HV_BINOP_EQ, 0, m, &cBinop_MQj0Hn18_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gMRCtTor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z2LzrOPJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_xcwAVw74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ocKt3dRl, 0, m, &cVar_ocKt3dRl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_EC1bJc73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_n7sxDU93_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_9iWNMcKR, 0, m, &cIf_9iWNMcKR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_9iWNMcKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_k3IMhPL2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_Zx9GJ8Or_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_RcmTLLWZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_MmIgYWTw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_pJhX2IhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ut35QbFx, HV_BINOP_POW, 0, m, &cBinop_ut35QbFx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ut35QbFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TrBX5jeQ, 0, m, &cIf_TrBX5jeQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0zhyRANt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_lbKjFTDH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_eTqpiQKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_PREDrhu1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IwI5buFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zx9GJ8Or, 0, m, &cIf_Zx9GJ8Or_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PREDrhu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zx9GJ8Or, 1, m, &cIf_Zx9GJ8Or_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MmIgYWTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_0zhyRANt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_RcmTLLWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_TrBX5jeQ, 0, m, &cIf_TrBX5jeQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lbKjFTDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ut35QbFx, HV_BINOP_POW, 1, m, &cBinop_ut35QbFx_sendMessage);
  cMsg_pJhX2IhF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_TrBX5jeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Fc086vnQ_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sr8rIfiK_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_PhVWBLYJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_n7sxDU93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9iWNMcKR, 1, m, &cIf_9iWNMcKR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_k3IMhPL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XkABplzS, HV_BINOP_GREATER_THAN, 1, m, &cBinop_XkABplzS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_13h0OGUL, HV_BINOP_EQ, 1, m, &cBinop_13h0OGUL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7KkXFb9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_m8X7J5jp, HV_BINOP_ADD, 0, m, &cBinop_m8X7J5jp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_m8X7J5jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eTqpiQKh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IwI5buFS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XkABplzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TrBX5jeQ, 1, m, &cIf_TrBX5jeQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_13h0OGUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C66rNWCW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_C66rNWCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Fc086vnQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sr8rIfiK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_PhVWBLYJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bMAyAoJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EC1bJc73, 0, m, &cVar_EC1bJc73_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Qb6LP61e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7KkXFb9s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_j7KiVLT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m8X7J5jp, HV_BINOP_ADD, 1, m, &cBinop_m8X7J5jp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XkABplzS, HV_BINOP_GREATER_THAN, 0, m, &cBinop_XkABplzS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_13h0OGUL, HV_BINOP_EQ, 0, m, &cBinop_13h0OGUL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_6YIJu8sL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uUEdJGIK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qQhRmKHB, 0, m, &cIf_qQhRmKHB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_qQhRmKHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ARAEyXZ7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_LY8HPMSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_AGeGDBSi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ECDOwMMJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_I04Vqccz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_soMAcZla, HV_BINOP_POW, 0, m, &cBinop_soMAcZla_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_soMAcZla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8hxW2RHk, 0, m, &cIf_8hxW2RHk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mk5E4ZYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_HpO3GvFF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZGaDzpzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UaL73tXd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Vr4gcIZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LY8HPMSa, 0, m, &cIf_LY8HPMSa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UaL73tXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LY8HPMSa, 1, m, &cIf_LY8HPMSa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ECDOwMMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_mk5E4ZYZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_AGeGDBSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_8hxW2RHk, 0, m, &cIf_8hxW2RHk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HpO3GvFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_soMAcZla, HV_BINOP_POW, 1, m, &cBinop_soMAcZla_sendMessage);
  cMsg_I04Vqccz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_8hxW2RHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_bY5BKyAj, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_uUEdJGIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qQhRmKHB, 1, m, &cIf_qQhRmKHB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ARAEyXZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fAlFhcDA, HV_BINOP_GREATER_THAN, 1, m, &cBinop_fAlFhcDA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_euKkhcCD, HV_BINOP_EQ, 1, m, &cBinop_euKkhcCD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_x3Cl3Nr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5ZXsv2LC, HV_BINOP_ADD, 0, m, &cBinop_5ZXsv2LC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5ZXsv2LC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZGaDzpzZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vr4gcIZi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fAlFhcDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8hxW2RHk, 1, m, &cIf_8hxW2RHk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_euKkhcCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0uamGXWK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_0uamGXWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bY5BKyAj, m);
}

void Heavy_WSTD_FL3NGR::cCast_kCNr4UCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6YIJu8sL, 0, m, &cVar_6YIJu8sL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6qH5PnHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x3Cl3Nr2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_YYtsnCs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5ZXsv2LC, HV_BINOP_ADD, 1, m, &cBinop_5ZXsv2LC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fAlFhcDA, HV_BINOP_GREATER_THAN, 0, m, &cBinop_fAlFhcDA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_euKkhcCD, HV_BINOP_EQ, 0, m, &cBinop_euKkhcCD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_mMRNk6Cb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_UEmzHYXP, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_z2IpkZ9J_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YgDwd5Tf, 0, m, &cSlice_YgDwd5Tf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NdvTSmuJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_YgDwd5Tf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9ecyphu6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9ecyphu6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_VeFGc12u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9ecyphu6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_9ecyphu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4PcKS3n1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_NdvTSmuJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_F7O7JVxl, 0, m, &cSlice_F7O7JVxl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jKRUdtqv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_F7O7JVxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9i1wnm7X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9i1wnm7X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_JevX9dny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9i1wnm7X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_9i1wnm7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RZgUYbzt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_lf5Y70Y0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JScPSLlB, 0, m, &cSlice_JScPSLlB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nEJDUq5b_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_JScPSLlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_C6YZwZsp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_C6YZwZsp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_kTg72Zao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C6YZwZsp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_C6YZwZsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hTNCnozZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_nEJDUq5b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_iPt14Z4R, 0, m, &cSlice_iPt14Z4R_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_iPt14Z4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gCNbx1UP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gCNbx1UP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_OvCi3CiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gCNbx1UP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_gCNbx1UP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Q93iLKsV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_v43ieFbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XO94InUB, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_tOc7gRoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IwnT8osJ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Mogg0LRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1tSHUBpq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_yRyR1CiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y4Bs0vJL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Lm3bZObI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6kJ4HPIP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GrOHhNoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HAF86xTS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_HAF86xTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4mAevPRk, HV_BINOP_DIVIDE, 1, m, &cBinop_4mAevPRk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nVL3gg3k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_zMO6oM4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_3QORkIzJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_LUUISgec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_zMO6oM4h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3QORkIzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4mAevPRk, HV_BINOP_DIVIDE, 0, m, &cBinop_4mAevPRk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nVL3gg3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LUUISgec_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4mAevPRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mTkhvvQo, HV_BINOP_MULTIPLY, 1, m, &cBinop_mTkhvvQo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mTkhvvQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3u7945Yb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NpJamGRh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_uyvQ0eZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_63INiuSZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_2RRBNOy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VyrhhGqv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_X5h0UHuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_I1UWsogs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_I1UWsogs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mTkhvvQo, HV_BINOP_MULTIPLY, 0, m, &cBinop_mTkhvvQo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VDpIHTK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_yYGeXDgo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yYGeXDgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hiLYsKEA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QN0aSjLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EninVmYG, 1, m, &cVar_EninVmYG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_EninVmYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zi2VHxdo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nvpJ9lMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vSmvCJUw, HV_BINOP_MULTIPLY, 1, m, &cBinop_vSmvCJUw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P96wp7Dp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nvpJ9lMu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gK80hIgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nHVu25Se_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nHVu25Se_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dR7vV5YF, HV_BINOP_MULTIPLY, 1, m, &cBinop_dR7vV5YF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZYAdVdy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MEQBFP0o, HV_BINOP_MULTIPLY, 1, m, &cBinop_MEQBFP0o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BPFzua5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZYAdVdy9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VMoLANXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qI53wpyx, HV_BINOP_MULTIPLY, 1, m, &cBinop_qI53wpyx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kFUsZ6GB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BWz0ZEbA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BWz0ZEbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UNa40Xfm, HV_BINOP_MULTIPLY, 1, m, &cBinop_UNa40Xfm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_pMv84C39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FEzfaHjn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_X5h0UHuG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_akXAos1u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_kQYzCoVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_VDpIHTK8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NpJamGRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_2RRBNOy6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3u7945Yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_uyvQ0eZO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_63INiuSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ApTsXFi0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_VyrhhGqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_A3Ya6c3t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_jIcOW0dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6tLJG1p0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_hiLYsKEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_V4mQxz2J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V4mQxz2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wbA9ZN5B, HV_BINOP_MULTIPLY, 1, m, &cBinop_wbA9ZN5B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wbA9ZN5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bRdL4UmF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bRdL4UmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jIcOW0dx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Zi2VHxdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xtbpykxx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xtbpykxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yQduARF1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dt47Bqia_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nd3E5wnx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zzWBnevE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9z1yppeJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4TFSfjF8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vSmvCJUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v43ieFbd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dR7vV5YF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tOc7gRoU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MEQBFP0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mogg0LRi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qI53wpyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yRyR1CiD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UNa40Xfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lm3bZObI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_WpmFA9Nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pMv84C39, 0, m, &cVar_pMv84C39_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_z3QXJk79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kQYzCoVM, 1, m, &cVar_kQYzCoVM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zzWBnevE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MEQBFP0o, HV_BINOP_MULTIPLY, 0, m, &cBinop_MEQBFP0o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Dt47Bqia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UNa40Xfm, HV_BINOP_MULTIPLY, 0, m, &cBinop_UNa40Xfm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9z1yppeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dR7vV5YF, HV_BINOP_MULTIPLY, 0, m, &cBinop_dR7vV5YF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yQduARF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_4TFSfjF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vSmvCJUw, HV_BINOP_MULTIPLY, 0, m, &cBinop_vSmvCJUw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nd3E5wnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qI53wpyx, HV_BINOP_MULTIPLY, 0, m, &cBinop_qI53wpyx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FEzfaHjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kQYzCoVM, 0, m, &cVar_kQYzCoVM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_akXAos1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EninVmYG, 0, m, &cVar_EninVmYG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5ZsFc2rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HV96rVHr, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_g3GEHOCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RXANE67b, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_62A7pJMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5MNSbdeg, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_gDPOU28M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pzCT4hjY, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_rqZp2ACq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_56KSKC51_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_56KSKC51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qZilGeaV, HV_BINOP_DIVIDE, 1, m, &cBinop_qZilGeaV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PD8LFvsd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_rLdGaARu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_cnPOGyum_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ff9UOyZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_rLdGaARu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cnPOGyum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qZilGeaV, HV_BINOP_DIVIDE, 0, m, &cBinop_qZilGeaV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PD8LFvsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ff9UOyZh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qZilGeaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r73uyglQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_r73uyglQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_r73uyglQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qsoGj4KT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pANT7WIw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_huzQJVW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fyz5NVC2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_0loC4FZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BGyWeSNh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wfdAgXxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ID6EKvOe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ID6EKvOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r73uyglQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_r73uyglQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_J7lbKGGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_NcLYmC87_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NcLYmC87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kKowqREW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_eig3bMY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LIe8lwSr, HV_BINOP_MULTIPLY, 1, m, &cBinop_LIe8lwSr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Nk0QcBBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xvSnNPUb, 1, m, &cVar_xvSnNPUb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3iw9fwzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UzXJC0fv, HV_BINOP_MULTIPLY, 1, m, &cBinop_UzXJC0fv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_14NqOFYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OhaYyPgd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OhaYyPgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qpsgnlye, HV_BINOP_MULTIPLY, 1, m, &cBinop_qpsgnlye_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_xvSnNPUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oxQZhV37_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ExNToFOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XIsanUCV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wfdAgXxp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IBSSKu4x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_v475UwPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_J7lbKGGM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qsoGj4KT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_huzQJVW0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pANT7WIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_0loC4FZK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_fyz5NVC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gXJU4R97_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_BGyWeSNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MAbXpYWb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_gXN8JWcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VqmEAq5y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_kKowqREW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KvwFhTEf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KvwFhTEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zVNWAwvP, HV_BINOP_MULTIPLY, 1, m, &cBinop_zVNWAwvP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zVNWAwvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CdV14u5x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CdV14u5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gXN8JWcA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_oxQZhV37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_79LFtfrm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_79LFtfrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zAgNr5Ua_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AIamo1t9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5kfnVYUL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XotgtgvB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h40jDz6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5ZsFc2rm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LIe8lwSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g3GEHOCB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UzXJC0fv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_62A7pJMs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qpsgnlye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gDPOU28M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_SFBkhWAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ExNToFOG, 0, m, &cVar_ExNToFOG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_t2vVzjKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v475UwPj, 1, m, &cVar_v475UwPj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XIsanUCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v475UwPj, 0, m, &cVar_v475UwPj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IBSSKu4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xvSnNPUb, 0, m, &cVar_xvSnNPUb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zAgNr5Ua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qpsgnlye, HV_BINOP_MULTIPLY, 0, m, &cBinop_qpsgnlye_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AIamo1t9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UzXJC0fv, HV_BINOP_MULTIPLY, 0, m, &cBinop_UzXJC0fv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XotgtgvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h40jDz6N, HV_BINOP_MULTIPLY, 0, m, &cBinop_h40jDz6N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5kfnVYUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LIe8lwSr, HV_BINOP_MULTIPLY, 0, m, &cBinop_LIe8lwSr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_R66oyWue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jf0rbMWq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_0XE59Jz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3fEsx5qr, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_dnCt1EFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SiHZ7RQP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7QbLrXPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4fsVbQVO, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_UB2vBkZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dw8s1xP8, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1R9bh2Uu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2vYhvdWG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_2vYhvdWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nFBlLGck, HV_BINOP_DIVIDE, 1, m, &cBinop_nFBlLGck_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F4pLIqzG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_H8ltE4Lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_RyYdZs7w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6Q6Od9iu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_H8ltE4Lr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RyYdZs7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nFBlLGck, HV_BINOP_DIVIDE, 0, m, &cBinop_nFBlLGck_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_F4pLIqzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6Q6Od9iu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nFBlLGck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_scOtA45K, HV_BINOP_MULTIPLY, 1, m, &cBinop_scOtA45K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_scOtA45K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_obGlQa4K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ntxzj2MT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_4K1R6nBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Nk6EfBB3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_zbCjD1eH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oLUN9JVB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_7TVlcd0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_HGn9VKl7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HGn9VKl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_scOtA45K, HV_BINOP_MULTIPLY, 0, m, &cBinop_scOtA45K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FanOw1nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_UrzgMGcV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UrzgMGcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d6BpD0W2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OJtwcv9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4fDjuA68, HV_BINOP_MULTIPLY, 1, m, &cBinop_4fDjuA68_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_esJO50C9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hM2dE82f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hM2dE82f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OJtwcv9w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vRxQAXLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vjLXOaLh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vjLXOaLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OGJi3UMB, HV_BINOP_MULTIPLY, 1, m, &cBinop_OGJi3UMB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IkJzYXak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QJEtxVyZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_QJEtxVyZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Z6HJBDUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6ZWBpGaR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6ZWBpGaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IkJzYXak_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_15DY9570_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_maathZDI, 1, m, &cVar_maathZDI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iviCexZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xsk4oTad, HV_BINOP_MULTIPLY, 1, m, &cBinop_Xsk4oTad_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XHIsmU2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1onq9BHy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1onq9BHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_67srapFr, HV_BINOP_MULTIPLY, 1, m, &cBinop_67srapFr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_maathZDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ajFAuqJ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_HTCoE6ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xe8bAHoS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_7TVlcd0K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ofPQStYo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_mxdB2esA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_FanOw1nt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Ntxzj2MT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_zbCjD1eH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_obGlQa4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_4K1R6nBi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_Nk6EfBB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wKNLmsU2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_oLUN9JVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HO7JmCI7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_h6V8sDH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dHQeoMVS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_d6BpD0W2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XqWXYebS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XqWXYebS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iYg94QOb, HV_BINOP_MULTIPLY, 1, m, &cBinop_iYg94QOb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iYg94QOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vmdyjczO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vmdyjczO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_h6V8sDH7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ajFAuqJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xDhK1HaU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xDhK1HaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x2pdCotk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mTYd0pwH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XAtHo5mq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PKPY9S8m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1nDA9bib_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gzMfqgjJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4fDjuA68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R66oyWue_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OGJi3UMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0XE59Jz0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QJEtxVyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dnCt1EFN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Xsk4oTad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7QbLrXPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_67srapFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UB2vBkZv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_TCFn9GEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HTCoE6ss, 0, m, &cVar_HTCoE6ss_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yNIJutli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mxdB2esA, 1, m, &cVar_mxdB2esA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gzMfqgjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4fDjuA68, HV_BINOP_MULTIPLY, 0, m, &cBinop_4fDjuA68_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1nDA9bib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OGJi3UMB, HV_BINOP_MULTIPLY, 0, m, &cBinop_OGJi3UMB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mTYd0pwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_67srapFr, HV_BINOP_MULTIPLY, 0, m, &cBinop_67srapFr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PKPY9S8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QJEtxVyZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_QJEtxVyZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_x2pdCotk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_XAtHo5mq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xsk4oTad, HV_BINOP_MULTIPLY, 0, m, &cBinop_Xsk4oTad_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ofPQStYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_maathZDI, 0, m, &cVar_maathZDI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xe8bAHoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mxdB2esA, 0, m, &cVar_mxdB2esA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Fc086vnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mMRNk6Cb, 1, m, &cIf_mMRNk6Cb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nrMChKSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UEmzHYXP, m);
}

void Heavy_WSTD_FL3NGR::cBinop_sr8rIfiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nrMChKSn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_PhVWBLYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mMRNk6Cb, 0, m, &cIf_mMRNk6Cb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_vF5gt0E4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C00vGkk1, HV_BINOP_DIVIDE, 0, m, &cBinop_C00vGkk1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_ajvubj2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8c6mLDaD, HV_BINOP_DIVIDE, 1, m, &cBinop_8c6mLDaD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_C00vGkk1, HV_BINOP_DIVIDE, 1, m, &cBinop_C00vGkk1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_V4Hm5yfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kQTbMsw8, HV_BINOP_DIVIDE, 0, m, &cBinop_kQTbMsw8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_pDGwKHR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kQTbMsw8, HV_BINOP_DIVIDE, 1, m, &cBinop_kQTbMsw8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_T2MsPTxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ajvubj2a, 0, m, &cVar_ajvubj2a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LJoSUS07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8c6mLDaD, HV_BINOP_DIVIDE, 0, m, &cBinop_8c6mLDaD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZkE5yE7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vF5gt0E4, 0, m, &cVar_vF5gt0E4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8c6mLDaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_V4Hm5yfh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_C00vGkk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_pDGwKHR8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kQTbMsw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_OJNPI9PO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_l74SrhdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_WygagTo9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iz5b5iOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_xfAaxR7U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OJNPI9PO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iz5b5iOR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xfAaxR7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_l74SrhdP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WygagTo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TjLtE23H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_thtU6vNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yZ4Svbcx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_LnZO4cei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hpKXGtyH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Qy8b6AUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r83fAo9C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_r3bV7kSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G2AhMGaU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Zz6R2HJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QPXISWAz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_9y3xMg3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HpyHGcZD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_3q9krZxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1yb4Tk7X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_dUAa4X63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bUYaBmvk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_1nuwXCvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YEDPZwrB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_5ot0bJ9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rnN4ytR7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_R5hucfn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5NVHSIMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_m4c2ASGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BnM1h7qR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LeMyZ1TS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DmUZML0e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DmUZML0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_9aJVyb0R, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8FKCeyw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gdy9oZj0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_gdy9oZj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZBS5WWYp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_pukDFlFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QU9ZnFie_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_roGut1j9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vJMr65zX_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jUBqAtow, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZBS5WWYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fOHhIhv3, m);
}

void Heavy_WSTD_FL3NGR::cMsg_QU9ZnFie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_roGut1j9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vJMr65zX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WAwhTfVj, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ATt4tCSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PQT2taHD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_PQT2taHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IgPLe9H5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_cmaAwCsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Q8FQ4T1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_h6eZI65f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RJF3ehcU_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SLgWPlA8, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IgPLe9H5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KEv0O5Lx, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8Q8FQ4T1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_h6eZI65f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RJF3ehcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0QkO7DvX, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bdKmStHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_YVsT9Pnl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YVsT9Pnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_s6TRjIhg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_fGXbZZYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XElNbaVI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_aOg6Kgbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pScZTZna_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_s6TRjIhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vKJq5TDJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vKJq5TDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eNHxGbop_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x40DlPq7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_x40DlPq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zUYtrofW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_eNHxGbop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_z0oIPIfI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z0oIPIfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HfIxSEXl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zUYtrofW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HfaAPD2L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HfaAPD2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qXWQ8lXO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HfIxSEXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_fGXbZZYq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qXWQ8lXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_aOg6Kgbe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qBztR3P5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7iNaZLIQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7iNaZLIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DrZ7TrdH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_7TedJymj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vfd3sgDh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_vfd3sgDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ukNBtf1U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_3sdr9e7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3sdr9e7l, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TZau7kl7, 0, m, &cDelay_TZau7kl7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3sdr9e7l, 0, m, &cDelay_3sdr9e7l_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_XqvP4pYX, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_TZau7kl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TZau7kl7, m);
  cMsg_NWl1w0EL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_FPCUtMZU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_PcXe6SZR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_hQs6RELA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WFCRFJY2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_2lX5gqRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_318FtSGx_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3sdr9e7l, 2, m, &cDelay_3sdr9e7l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h8nOs3p4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WFCRFJY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_2lX5gqRc, 0, m, &hTable_2lX5gqRc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ukNBtf1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_hQs6RELA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NWl1w0EL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_2lX5gqRc, 0, m, &hTable_2lX5gqRc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_h8nOs3p4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3sdr9e7l, 0, m, &cDelay_3sdr9e7l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_318FtSGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_TZau7kl7, 2, m, &cDelay_TZau7kl7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PcXe6SZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_XqvP4pYX, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_jx0J7b9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ilIso28J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ilIso28J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_e846Ttip_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_YPyhatBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YPyhatBL, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iGkqxYCg, 0, m, &cDelay_iGkqxYCg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YPyhatBL, 0, m, &cDelay_YPyhatBL_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KT1J7g8Y, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_iGkqxYCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iGkqxYCg, m);
  cMsg_7NgVDYNK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_imLH2vNC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wJbvARIC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_aWCKaKPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6caY39fm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_XemrnLTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qSPAWPbj_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YPyhatBL, 2, m, &cDelay_YPyhatBL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X48hzEw5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6caY39fm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_XemrnLTp, 0, m, &hTable_XemrnLTp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_e846Ttip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_aWCKaKPY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7NgVDYNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_XemrnLTp, 0, m, &hTable_XemrnLTp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_X48hzEw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YPyhatBL, 0, m, &cDelay_YPyhatBL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qSPAWPbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_iGkqxYCg, 2, m, &cDelay_iGkqxYCg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wJbvARIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KT1J7g8Y, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_No0kPkwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dEGLT7iH, HV_BINOP_MULTIPLY, 0, m, &cBinop_dEGLT7iH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_35wvGsq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CZ5KhhsG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_CZ5KhhsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XK70VtQw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dEGLT7iH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_aBcoUFWt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q238vJGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dEGLT7iH, HV_BINOP_MULTIPLY, 1, m, &cBinop_dEGLT7iH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XK70VtQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_q238vJGx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aBcoUFWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_x8eMWwfm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x8eMWwfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_4FSb6FhQ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qRuryY0w, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4FSb6FhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wFn0n7gK, m);
}

void Heavy_WSTD_FL3NGR::cVar_QhQ0KyZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MCWzvUKy, HV_BINOP_MULTIPLY, 0, m, &cBinop_MCWzvUKy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_R8Ft1PzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Onwx65sw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Onwx65sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HMv1uiVp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MCWzvUKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Gxb4hQyZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_L3JXURf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MCWzvUKy, HV_BINOP_MULTIPLY, 1, m, &cBinop_MCWzvUKy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HMv1uiVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_L3JXURf1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Gxb4hQyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZSDVcJOT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZSDVcJOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RdvlIUU6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_n77kZjr9, m);
}

void Heavy_WSTD_FL3NGR::cBinop_RdvlIUU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_km37HkCW, m);
}

void Heavy_WSTD_FL3NGR::cMsg_DrZ7TrdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JgQJaJX7, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_vDuXeZt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_jgfG4Gb4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ie2K0Uos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_vDuXeZt7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CL7D5axa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lQbXtpzt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xeQXj6aN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7bX2jfKu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7bX2jfKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EeKnXP0q, HV_BINOP_MULTIPLY, 1, m, &cBinop_EeKnXP0q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lQbXtpzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_xeQXj6aN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EeKnXP0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4C1hRYd6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jgfG4Gb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EeKnXP0q, HV_BINOP_MULTIPLY, 0, m, &cBinop_EeKnXP0q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4C1hRYd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D02bjvEp, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_SrTwg6CD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_AHenmsJN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AHenmsJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CL7D5axa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ie2K0Uos_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_D7KEH6mX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_M28oCU4g, 0, m, &cSlice_M28oCU4g_sendMessage);
      break;
    }
    default: {
      cSwitchcase_t7lPcmwy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_M28oCU4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_a4GHqWNE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_a4GHqWNE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_DMDnpgiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_a4GHqWNE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_a4GHqWNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_70M8885L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_t7lPcmwy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2BkJFzPQ, 0, m, &cSlice_2BkJFzPQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IRzqLu4g_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_2BkJFzPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gxFZy8d6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gxFZy8d6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_MQ7dbIdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gxFZy8d6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_gxFZy8d6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LUz7pmwr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_IRzqLu4g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PD85QxnJ, 0, m, &cSlice_PD85QxnJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_d0YuBc7S_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_PD85QxnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6OYtOnKv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6OYtOnKv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Qts9iSEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6OYtOnKv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_6OYtOnKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kp6GbQDK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_d0YuBc7S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_b24apefb, 0, m, &cSlice_b24apefb_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_b24apefb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6ZQVTSye_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6ZQVTSye_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_PGZAgHBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6ZQVTSye_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_6ZQVTSye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_m7UtTthi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_XElNbaVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jWUo5u90, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_pScZTZna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MsL9J8su, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_5blqmqKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_VniyRjdI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VniyRjdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_P1aYn4C3, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_gIBRa7mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IOsDUZia_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_IOsDUZia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kXxICdbZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_o9eBPytx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GSkhWrbW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_BnjZSwkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_x8KPBNwa_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SSDOP5q4, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kXxICdbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_YXdOUsaG, m);
}

void Heavy_WSTD_FL3NGR::cMsg_GSkhWrbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BnjZSwkr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x8KPBNwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6fd0OvF4, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ycQsC0HW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0bd86kIv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_0bd86kIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vYSzCXu3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_2JC6cpn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YdF4La9W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_9kbu6VPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5hIcmUnA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xE1cvTNp, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vYSzCXu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0WIpCIEm, m);
}

void Heavy_WSTD_FL3NGR::cMsg_YdF4La9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9kbu6VPV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5hIcmUnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vwYubBaA, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rTCVPaXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DNePCFFw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DNePCFFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_hSrob53b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_AzsrGAwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LmsTIcwM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_gzfqunSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ib6GFJWB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hSrob53b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BAMylmq9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BAMylmq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2zptIkmE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mc9spf6y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2zptIkmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wjsFSjoj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mc9spf6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nCxn9jcE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wjsFSjoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_O8sMCB36_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nCxn9jcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EEX5Wp7U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EEX5Wp7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ms6OMoim_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_O8sMCB36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_AzsrGAwx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ms6OMoim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_gzfqunSp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BFpJJzbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_P11nP1lS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P11nP1lS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4k7qvZ1m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_PSvwOTki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Ka2BtWSh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Ka2BtWSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0rjhnh9A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_Xuy6Pheq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Xuy6Pheq, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aOTvSI5C, 0, m, &cDelay_aOTvSI5C_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xuy6Pheq, 0, m, &cDelay_Xuy6Pheq_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YYHhZwXI, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_aOTvSI5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aOTvSI5C, m);
  cMsg_N68uxRbL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_t9Hg1T3Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_4tcDFRuE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_NahAFlyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xhtgn1BR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_uAvbyeOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NuM8vARx_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xuy6Pheq, 2, m, &cDelay_Xuy6Pheq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hEVEvWut_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xhtgn1BR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_uAvbyeOZ, 0, m, &hTable_uAvbyeOZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0rjhnh9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_NahAFlyh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_N68uxRbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_uAvbyeOZ, 0, m, &hTable_uAvbyeOZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hEVEvWut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xuy6Pheq, 0, m, &cDelay_Xuy6Pheq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NuM8vARx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_aOTvSI5C, 2, m, &cDelay_aOTvSI5C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4tcDFRuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YYHhZwXI, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_svzjbUby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_F2OuXwdW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_F2OuXwdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HnJzw1tW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_xRDC0y0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xRDC0y0q, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_J3i8wwN6, 0, m, &cDelay_J3i8wwN6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xRDC0y0q, 0, m, &cDelay_xRDC0y0q_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LocFsqbM, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_J3i8wwN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_J3i8wwN6, m);
  cMsg_lY2MR1Kv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_vsFSuL34_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wVY3Pgp7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_0DYa3Adc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UQtMdNnh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_NzyXuNHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OQAzg5Dx_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xRDC0y0q, 2, m, &cDelay_xRDC0y0q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x14BEq3S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UQtMdNnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_NzyXuNHt, 0, m, &hTable_NzyXuNHt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HnJzw1tW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_0DYa3Adc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_lY2MR1Kv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_NzyXuNHt, 0, m, &hTable_NzyXuNHt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_x14BEq3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xRDC0y0q, 0, m, &cDelay_xRDC0y0q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OQAzg5Dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_J3i8wwN6, 2, m, &cDelay_J3i8wwN6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wVY3Pgp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LocFsqbM, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_BRNkRMrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r9Zpr0Ct, HV_BINOP_MULTIPLY, 0, m, &cBinop_r9Zpr0Ct_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_v69byDb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lXhuAiq2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_lXhuAiq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XlP8xj4Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_r9Zpr0Ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SoF4i4E7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BulqIXGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r9Zpr0Ct, HV_BINOP_MULTIPLY, 1, m, &cBinop_r9Zpr0Ct_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XlP8xj4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BulqIXGL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SoF4i4E7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_psAHnokX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_psAHnokX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_2R1xRUXc_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hbCpFVE3, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2R1xRUXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FAHzwACk, m);
}

void Heavy_WSTD_FL3NGR::cVar_N9mGXkbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QClPrFpq, HV_BINOP_MULTIPLY, 0, m, &cBinop_QClPrFpq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_s62zbCXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6GZrY3m1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_6GZrY3m1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vPGfI6lW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QClPrFpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yuZbQoYv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_C6RhmgUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QClPrFpq, HV_BINOP_MULTIPLY, 1, m, &cBinop_QClPrFpq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vPGfI6lW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_C6RhmgUE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yuZbQoYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xht09gT7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xht09gT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_avz6IlAw_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_winWvuh6, m);
}

void Heavy_WSTD_FL3NGR::cBinop_avz6IlAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QwEwhZFr, m);
}

void Heavy_WSTD_FL3NGR::cMsg_4k7qvZ1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GNLqYMxw, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_0vMXllDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_nU3QqZi3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nIkTIITc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_0vMXllDn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mHj8TTWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cema99Zh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oQik2v16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_WIF66AQY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WIF66AQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sSI9gAUF, HV_BINOP_MULTIPLY, 1, m, &cBinop_sSI9gAUF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cema99Zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_oQik2v16_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sSI9gAUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qKdrqudH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nU3QqZi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sSI9gAUF, HV_BINOP_MULTIPLY, 0, m, &cBinop_sSI9gAUF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qKdrqudH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N4Y2cMiR, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_Sl9Zcpuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_LmsTc6LL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LmsTc6LL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mHj8TTWC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nIkTIITc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_jZ9JV3Q0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XzwGtDnM, 0, m, &cSlice_XzwGtDnM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MASHN0B3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_XzwGtDnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AbPNIGwu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AbPNIGwu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_gEqQ2jRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AbPNIGwu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_AbPNIGwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_i2Q7REZu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_MASHN0B3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Qpec9Fli, 0, m, &cSlice_Qpec9Fli_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jt8PyMFv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Qpec9Fli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ztvE2mPc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ztvE2mPc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_v7wtpgCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ztvE2mPc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ztvE2mPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wRdmzufk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_jt8PyMFv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tjryGecy, 0, m, &cSlice_tjryGecy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_aqTwNpOl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_tjryGecy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QEJ6BfeR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QEJ6BfeR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ifwx1cj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QEJ6BfeR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_QEJ6BfeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FcYBx1AJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_aqTwNpOl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WE6MH1o5, 0, m, &cSlice_WE6MH1o5_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_WE6MH1o5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2nPqYciy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2nPqYciy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_zET3sh3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2nPqYciy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_2nPqYciy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_O4o7he7f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_LmsTIcwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zLll0frz, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Ib6GFJWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nEFnEVxG, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_7VQw0jAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qxaKo15W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qxaKo15W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_b1V2X8lq, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_K3qj6au5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lOED1siG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_lOED1siG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZQv5kEHJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_90BBDfMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lo7cZQsA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_HOYKqBXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9WqnWZb3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QsekSImd, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZQv5kEHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_POEhNnca, m);
}

void Heavy_WSTD_FL3NGR::cMsg_lo7cZQsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HOYKqBXT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9WqnWZb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dg7ARkQV, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ihVjRPpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YQAKXKSq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_YQAKXKSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BwCiEXn8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_mAD5lq1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xy58bIwu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_IugNVDHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UOPjOCzB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jNHka5Lc, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BwCiEXn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lfAfd0n9, m);
}

void Heavy_WSTD_FL3NGR::cMsg_xy58bIwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IugNVDHI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UOPjOCzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MW4sYOOY, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rTZ999em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_uVTKQYNU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uVTKQYNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_w8IlgXyN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_D0fmwXgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3tPTGb5i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_7yeVZuuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EC9Ss2fq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_w8IlgXyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SNmdOYUf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SNmdOYUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IErshi0A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kj67jYkI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IErshi0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kVCNsJfX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kj67jYkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SRfTbvtq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kVCNsJfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mGlbtbkS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_SRfTbvtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NrLKJNT0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NrLKJNT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XaFBgNxY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mGlbtbkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_D0fmwXgR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XaFBgNxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_7yeVZuuU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZdacqTdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_cjb9UPdi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cjb9UPdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N4RW3GiL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BIxZiIdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IbBQWKtj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_IbBQWKtj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lEGMfNrK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_RR8AdrYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RR8AdrYI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y1x8M6GC, 0, m, &cDelay_y1x8M6GC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RR8AdrYI, 0, m, &cDelay_RR8AdrYI_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_FEytsZ1V, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_y1x8M6GC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y1x8M6GC, m);
  cMsg_OwFe999z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_IdOIRvJt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_yQcKpCrb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_0F3UweYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GdhkDLm9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_ju1CVtu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4CDW3045_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RR8AdrYI, 2, m, &cDelay_RR8AdrYI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jNSm9COj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GdhkDLm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ju1CVtu7, 0, m, &hTable_ju1CVtu7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lEGMfNrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_0F3UweYz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OwFe999z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ju1CVtu7, 0, m, &hTable_ju1CVtu7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jNSm9COj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RR8AdrYI, 0, m, &cDelay_RR8AdrYI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4CDW3045_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_y1x8M6GC, 2, m, &cDelay_y1x8M6GC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yQcKpCrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_FEytsZ1V, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_uPjJXqIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7jU3EPzS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_7jU3EPzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HJYIotAE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_u7xhMnrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_u7xhMnrf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AgyerBrJ, 0, m, &cDelay_AgyerBrJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u7xhMnrf, 0, m, &cDelay_u7xhMnrf_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_g5LYvN3q, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_AgyerBrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AgyerBrJ, m);
  cMsg_fsGp0KZp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_dTZdOd63_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_akng0tIO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_uMspt4X2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7M1kHPWl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_bxHFxKUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3QoSIL6K_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u7xhMnrf, 2, m, &cDelay_u7xhMnrf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uSfCd6Vj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7M1kHPWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_bxHFxKUP, 0, m, &hTable_bxHFxKUP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HJYIotAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_uMspt4X2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fsGp0KZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_bxHFxKUP, 0, m, &hTable_bxHFxKUP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uSfCd6Vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_u7xhMnrf, 0, m, &cDelay_u7xhMnrf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3QoSIL6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_AgyerBrJ, 2, m, &cDelay_AgyerBrJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_akng0tIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_g5LYvN3q, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_BchcgEPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GpRZ9yV6, HV_BINOP_MULTIPLY, 0, m, &cBinop_GpRZ9yV6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EAEtKWyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mOQUuJbo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_mOQUuJbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EhIxrSFb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_GpRZ9yV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_B6zbJgHI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0TrL9Msi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GpRZ9yV6, HV_BINOP_MULTIPLY, 1, m, &cBinop_GpRZ9yV6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EhIxrSFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0TrL9Msi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_B6zbJgHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_G7YFtEZY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G7YFtEZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_2qAZCApR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Wmggisut, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2qAZCApR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_P5HBwiX6, m);
}

void Heavy_WSTD_FL3NGR::cVar_1MSsQsFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ptelfLVi, HV_BINOP_MULTIPLY, 0, m, &cBinop_ptelfLVi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_e9CtHtM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ltUIx1Ke_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ltUIx1Ke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dBrErurJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ptelfLVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ceXbwIVK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DYwWd573_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ptelfLVi, HV_BINOP_MULTIPLY, 1, m, &cBinop_ptelfLVi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dBrErurJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DYwWd573_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ceXbwIVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_AJXFK877_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AJXFK877_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NNxuuuug_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0DjG9aqW, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NNxuuuug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TfgoQ8dY, m);
}

void Heavy_WSTD_FL3NGR::cMsg_N4RW3GiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QSvHzqnz, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_nVcqGO2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_Dwj8DpB3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_s2DXBPqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RfLAZxsH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vsbXkSCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_nVcqGO2p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LsaSylAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3ThxFyi8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3ThxFyi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0mWs9mIa, HV_BINOP_MULTIPLY, 1, m, &cBinop_0mWs9mIa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RfLAZxsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_LsaSylAQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0mWs9mIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v3bfp4RK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Dwj8DpB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0mWs9mIa, HV_BINOP_MULTIPLY, 0, m, &cBinop_0mWs9mIa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_v3bfp4RK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K0iaxXYP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_5acAzhxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_uZOcR46p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uZOcR46p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s2DXBPqS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vsbXkSCh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_j2bUzxVL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4IOnxRi0, 0, m, &cSlice_4IOnxRi0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GkAwQe7Y_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_4IOnxRi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OCxFx8PQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OCxFx8PQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_lGPtcbbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OCxFx8PQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_OCxFx8PQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sOcaS8w1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_GkAwQe7Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_H6zjOTqw, 0, m, &cSlice_H6zjOTqw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_14PZQQAg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_H6zjOTqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wW85d27h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wW85d27h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_1REYUMkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wW85d27h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_wW85d27h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gxQeOPQk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_14PZQQAg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MtRP13VJ, 0, m, &cSlice_MtRP13VJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gvipZSWo_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_MtRP13VJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6Yz8t8If_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6Yz8t8If_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_1EWY9FoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6Yz8t8If_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_6Yz8t8If_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UVhWR9MI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_gvipZSWo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ose4d9Zx, 0, m, &cSlice_Ose4d9Zx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Ose4d9Zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eqojB7Cz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eqojB7Cz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_E1AFvY0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eqojB7Cz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_eqojB7Cz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5rBPoANg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_3tPTGb5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ImUKVPac, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_EC9Ss2fq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5L0M5YbT, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3SqHMEdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xbZ9zjRp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_z2IpkZ9J_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_aMb1iQB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xbZ9zjRp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_z2IpkZ9J_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hYY0oCEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xbZ9zjRp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_z2IpkZ9J_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_s3nkwdWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xbZ9zjRp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_z2IpkZ9J_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_TjLtE23H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xbZ9zjRp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_z2IpkZ9J_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_aEYHzRHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ZRhC6tje, 0, m, &cVar_ZRhC6tje_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_V2XntbEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_C3rRUzbP, 0, m, &cVar_C3rRUzbP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tDJmTRHd, 0, m, &cVar_tDJmTRHd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GYZpPQcO, 0, m, &cVar_GYZpPQcO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_G2AhMGaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_D7KEH6mX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_yZ4Svbcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_D7KEH6mX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hpKXGtyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_D7KEH6mX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_r83fAo9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_D7KEH6mX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_0fUAgBax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r3bV7kSu, 0, m, &cVar_r3bV7kSu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9ZEFVlxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_thtU6vNH, 0, m, &cVar_thtU6vNH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_B14qreVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Qy8b6AUR, 0, m, &cVar_Qy8b6AUR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bUYaBmvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jZ9JV3Q0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QPXISWAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jZ9JV3Q0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_HpyHGcZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jZ9JV3Q0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1yb4Tk7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jZ9JV3Q0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_hKxZQBrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dUAa4X63, 0, m, &cVar_dUAa4X63_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SKapMZ4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zz6R2HJx, 0, m, &cVar_Zz6R2HJx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ySFLQSX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3q9krZxu, 0, m, &cVar_3q9krZxu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_BnM1h7qR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_j2bUzxVL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YEDPZwrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_j2bUzxVL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_rnN4ytR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_j2bUzxVL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_5NVHSIMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_j2bUzxVL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_hPB8umH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m4c2ASGg, 0, m, &cVar_m4c2ASGg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_anf5M6Dd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1nuwXCvF, 0, m, &cVar_1nuwXCvF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xzVpb6J4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R5hucfn5, 0, m, &cVar_R5hucfn5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_CBJLpZZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C3rRUzbP, 0, m, &cVar_C3rRUzbP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vhCipZcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tDJmTRHd, 0, m, &cVar_tDJmTRHd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_aQwd4fdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GYZpPQcO, 0, m, &cVar_GYZpPQcO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0JFJh7BK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9A1Gx6jV, 0, m, &cVar_9A1Gx6jV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_JoYfFurI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zAnii2F0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rjjxRCiY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_wtMu8bJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M2ZvC0SP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dCQhVIOL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IPpzxdge_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xAojO73w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tUAH3m4L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uBWKPwoS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J2d65VsD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ASKSfpp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRei54X4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N0MUchBa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2CcbO7VA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_cZQCHkza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wRyTMHl6_sendMessage(_c, 0, m);
  cMsg_xorwMsP8_sendMessage(_c, 0, m);
  cMsg_YK1E7uV0_sendMessage(_c, 0, m);
  cMsg_GrOHhNoD_sendMessage(_c, 0, m);
  cMsg_rqZp2ACq_sendMessage(_c, 0, m);
  cMsg_1R9bh2Uu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0sZFIhVp, 0, m, &cVar_0sZFIhVp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9A1Gx6jV, 0, m, &cVar_9A1Gx6jV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5fUZoFyy, 0, m, &cVar_5fUZoFyy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pMv84C39, 0, m, &cVar_pMv84C39_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ExNToFOG, 0, m, &cVar_ExNToFOG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HTCoE6ss, 0, m, &cVar_HTCoE6ss_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_M8F2rzko, 0, m, &cVar_M8F2rzko_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iP6B7EEd, 0, m, &cVar_iP6B7EEd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7XbNmT7w, 0, m, &cVar_7XbNmT7w_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v68XBxJt, 0, m, &cVar_v68XBxJt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wsFLXy6I, 0, m, &cVar_wsFLXy6I_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_a39QNV78, 0, m, &cVar_a39QNV78_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FAzoYSKS, 0, m, &cVar_FAzoYSKS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bdxy6kBE, 0, m, &cVar_bdxy6kBE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_W5JzeQlN, 0, m, &cVar_W5JzeQlN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ocKt3dRl, 0, m, &cVar_ocKt3dRl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EC1bJc73, 0, m, &cVar_EC1bJc73_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6YIJu8sL, 0, m, &cVar_6YIJu8sL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VeFGc12u, 0, m, &cVar_VeFGc12u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JevX9dny, 0, m, &cVar_JevX9dny_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kTg72Zao, 0, m, &cVar_kTg72Zao_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OvCi3CiE, 0, m, &cVar_OvCi3CiE_sendMessage);
  cMsg_35wvGsq7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_No0kPkwV, 0, m, &cVar_No0kPkwV_sendMessage);
  cMsg_R8Ft1PzN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QhQ0KyZY, 0, m, &cVar_QhQ0KyZY_sendMessage);
  cMsg_v69byDb3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BRNkRMrn, 0, m, &cVar_BRNkRMrn_sendMessage);
  cMsg_s62zbCXl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_N9mGXkbV, 0, m, &cVar_N9mGXkbV_sendMessage);
  cMsg_EAEtKWyz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BchcgEPk, 0, m, &cVar_BchcgEPk_sendMessage);
  cMsg_e9CtHtM6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1MSsQsFV, 0, m, &cVar_1MSsQsFV_sendMessage);
  cMsg_7TedJymj_sendMessage(_c, 0, m);
  cMsg_jx0J7b9u_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DMDnpgiQ, 0, m, &cVar_DMDnpgiQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MQ7dbIdB, 0, m, &cVar_MQ7dbIdB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Qts9iSEK, 0, m, &cVar_Qts9iSEK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PGZAgHBV, 0, m, &cVar_PGZAgHBV_sendMessage);
  cMsg_PSvwOTki_sendMessage(_c, 0, m);
  cMsg_svzjbUby_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gEqQ2jRO, 0, m, &cVar_gEqQ2jRO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v7wtpgCX, 0, m, &cVar_v7wtpgCX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ifwx1cj4, 0, m, &cVar_ifwx1cj4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zET3sh3f, 0, m, &cVar_zET3sh3f_sendMessage);
  cMsg_BIxZiIdr_sendMessage(_c, 0, m);
  cMsg_uPjJXqIX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lGPtcbbU, 0, m, &cVar_lGPtcbbU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1REYUMkQ, 0, m, &cVar_1REYUMkQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1EWY9FoD, 0, m, &cVar_1EWY9FoD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E1AFvY0C, 0, m, &cVar_E1AFvY0C_sendMessage);
  cMsg_V2XntbEf_sendMessage(_c, 0, m);
  cMsg_aEYHzRHB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pukDFlFG, 0, m, &cVar_pukDFlFG_sendMessage);
  cMsg_8FKCeyw7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cmaAwCsW, 0, m, &cVar_cmaAwCsW_sendMessage);
  cMsg_ATt4tCSV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_o9eBPytx, 0, m, &cVar_o9eBPytx_sendMessage);
  cMsg_gIBRa7mp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2JC6cpn5, 0, m, &cVar_2JC6cpn5_sendMessage);
  cMsg_ycQsC0HW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_90BBDfMX, 0, m, &cVar_90BBDfMX_sendMessage);
  cMsg_K3qj6au5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mAD5lq1j, 0, m, &cVar_mAD5lq1j_sendMessage);
  cMsg_ihVjRPpL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_XSrcxAVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5EnENux9, HV_BINOP_MULTIPLY, 0, m, &cBinop_5EnENux9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_43baf0o5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_82fwS8Ke_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TT6lZCcE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_U7IoV9uL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_U0Xe7z0Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_gHuKSG1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MYLBcbZg_sendMessage);
  cMsg_65Lwr9rg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_Mc6BovkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vjRoZxnY, HV_BINOP_MULTIPLY, 0, m, &cBinop_vjRoZxnY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_GdaHn77H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_1qHlaul8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9dMpD36X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9KDKacHc, HV_BINOP_MULTIPLY, 1, m, &cBinop_9KDKacHc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JLuLDTH7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mpMpRyEM_sendMessage);
  cMsg_Pt3SoxX1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_ALguVv42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VTJpjnAh, HV_BINOP_MULTIPLY, 0, m, &cBinop_VTJpjnAh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Ja2DyNmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ieeqz1pa_sendMessage(_c, 0, m);
  cMsg_EFLGKzAa_sendMessage(_c, 0, m);
  cMsg_7ZN49EBH_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_cZNpVhgq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vMmks9w8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2bYwYI7W_sendMessage);
  cMsg_qxcn52TW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_QyA0HGsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ExNToFOG, 0, m, &cVar_ExNToFOG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Q93iLKsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t2vVzjKR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SFBkhWAd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_4PcKS3n1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xcwAVw74_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KoFqa2Cd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gMRCtTor_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_hTNCnozZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kCNr4UCJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YYtsnCs1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6qH5PnHB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_RZgUYbzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bMAyAoJM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j7KiVLT1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qb6LP61e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ApTsXFi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wbA9ZN5B, HV_BINOP_MULTIPLY, 0, m, &cBinop_wbA9ZN5B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_A3Ya6c3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_P96wp7Dp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gK80hIgO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BPFzua5Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_VMoLANXV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6tLJG1p0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QN0aSjLB_sendMessage);
  cMsg_kFUsZ6GB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_gXJU4R97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zVNWAwvP, HV_BINOP_MULTIPLY, 0, m, &cBinop_zVNWAwvP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_MAbXpYWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_3iw9fwzf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VqmEAq5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h40jDz6N, HV_BINOP_MULTIPLY, 1, m, &cBinop_h40jDz6N_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_eig3bMY0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Nk0QcBBp_sendMessage);
  cMsg_14NqOFYy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_wKNLmsU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iYg94QOb, HV_BINOP_MULTIPLY, 0, m, &cBinop_iYg94QOb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_HO7JmCI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_esJO50C9_sendMessage(_c, 0, m);
  cMsg_vRxQAXLO_sendMessage(_c, 0, m);
  cMsg_Z6HJBDUP_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_iviCexZi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_dHQeoMVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_15DY9570_sendMessage);
  cMsg_XHIsmU2P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_7aCclhGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZRhC6tje, 0, m, &cVar_ZRhC6tje_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_GxMGoTbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_0fUAgBax_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_S7sJsr7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_9ZEFVlxX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zRsf0x1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LnZO4cei, 0, m, &cVar_LnZO4cei_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Km6q5nGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_B14qreVm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_YpObIOYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_hKxZQBrr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vfbt3mQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_SKapMZ4C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_TL51TVQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9y3xMg3g, 0, m, &cVar_9y3xMg3g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_16ZjOzdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ySFLQSX7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_guWj735h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_hPB8umH4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Pl86Ug18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_anf5M6Dd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Q56FsVzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5ot0bJ9F, 0, m, &cVar_5ot0bJ9F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_V7dKYhGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_xzVpb6J4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_kp6GbQDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_LeMyZ1TS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LUz7pmwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SrTwg6CD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_m7UtTthi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_bdKmStHf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_70M8885L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qBztR3P5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_FcYBx1AJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_5blqmqKl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_wRdmzufk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Sl9Zcpuw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_O4o7he7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rTCVPaXV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_i2Q7REZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BFpJJzbT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_UVhWR9MI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_7VQw0jAR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_gxQeOPQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5acAzhxR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_5rBPoANg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rTZ999em_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_sOcaS8w1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZdacqTdt_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_BAtMbQMi, VOf(Bf0));
    __hv_line_f(&sLine_XmVcqxbq, VOf(Bf1));
    __hv_line_f(&sLine_1cPIjekD, VOf(Bf2));
    __hv_line_f(&sLine_yUnli8pc, VOf(Bf3));
    __hv_line_f(&sLine_HaLuVI0U, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_3idbMofC, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_W8twbb8y, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_uOptjXkc, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_dX8PqkGq, VOf(Bf1));
    __hv_line_f(&sLine_7GAMG7ym, VOf(Bf0));
    __hv_line_f(&sLine_LCKD4qD0, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_3I9JdT26, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_r0Nn8xur, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_M2Ks7NV4, VOf(Bf5));
    __hv_line_f(&sLine_TuM1ID7T, VOf(Bf1));
    __hv_line_f(&sLine_FTJyxfzP, VOf(Bf2));
    __hv_line_f(&sLine_yZN9i7Fx, VOf(Bf4));
    __hv_line_f(&sLine_yy79Plzu, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_ShsqzL1g, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_aIYBhML3, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_XO94InUB, VOf(Bf6));
    __hv_line_f(&sLine_IwnT8osJ, VOf(Bf2));
    __hv_line_f(&sLine_1tSHUBpq, VOf(Bf1));
    __hv_line_f(&sLine_Y4Bs0vJL, VOf(Bf5));
    __hv_line_f(&sLine_6kJ4HPIP, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_8xu7kkeb, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_bbmbK63f, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_HV96rVHr, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_RXANE67b, VOf(Bf2));
    __hv_line_f(&sLine_5MNSbdeg, VOf(Bf6));
    __hv_line_f(&sLine_pzCT4hjY, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_PqLZclDg, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_UEmzHYXP, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_Jf0rbMWq, VOf(Bf8));
    __hv_line_f(&sLine_3fEsx5qr, VOf(Bf2));
    __hv_line_f(&sLine_SiHZ7RQP, VOf(Bf1));
    __hv_line_f(&sLine_4fsVbQVO, VOf(Bf7));
    __hv_line_f(&sLine_Dw8s1xP8, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_ucWm9oMp, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_bY5BKyAj, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_MsL9J8su, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_9aJVyb0R, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_JgQJaJX7, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_qRuryY0w, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_wFn0n7gK, VOf(Bf8));
    __hv_rpole_f(&sRPole_SpTEwTHH, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_n77kZjr9, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_km37HkCW, VOf(Bf10));
    __hv_rpole_f(&sRPole_XVLLIf03, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_DmxnMotw, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_fOHhIhv3, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_WAwhTfVj, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_jUBqAtow, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_78BPzzwn, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_DSTo8ssZ, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_jWUo5u90, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_FPq95wLU, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_KEv0O5Lx, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_0QkO7DvX, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_SLgWPlA8, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Id7Hs0bn, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_qQAHg8JW, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_D02bjvEp, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_XqvP4pYX, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_KT1J7g8Y, VIf(Bf3));
    __hv_varwrite_f(&sVarf_qMGfJFv2, VIf(Bf11));
    __hv_line_f(&sLine_nEFnEVxG, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_P1aYn4C3, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_GNLqYMxw, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_hbCpFVE3, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_FAHzwACk, VOf(Bf10));
    __hv_rpole_f(&sRPole_kTYAFi6O, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_winWvuh6, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_QwEwhZFr, VOf(Bf5));
    __hv_rpole_f(&sRPole_Q2fufyrU, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_rgGZKacQ, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_YXdOUsaG, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_6fd0OvF4, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_SSDOP5q4, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_nVhMEuJA, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_KOT3L61h, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_zLll0frz, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_78f8vuef, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_0WIpCIEm, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_vwYubBaA, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_xE1cvTNp, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_xkhaP8jN, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_PYEc1sBx, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_N4Y2cMiR, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_YYHhZwXI, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_LocFsqbM, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Ov8qt39V, VIf(Bf8));
    __hv_line_f(&sLine_5L0M5YbT, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_b1V2X8lq, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_QSvHzqnz, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_Wmggisut, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_P5HBwiX6, VOf(Bf5));
    __hv_rpole_f(&sRPole_wIopbpih, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_0DjG9aqW, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_TfgoQ8dY, VOf(Bf6));
    __hv_rpole_f(&sRPole_nGRP2xaA, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_aZ4T8giN, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_POEhNnca, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_dg7ARkQV, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_QsekSImd, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_f2KQExVG, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_kugqhPjT, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_ImUKVPac, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_lpMBpO95, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_lfAfd0n9, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_MW4sYOOY, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_jNHka5Lc, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_2MlOMaOQ, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_yTBl08gp, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_K0iaxXYP, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_FEytsZ1V, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_g5LYvN3q, VIf(Bf4));
    __hv_varwrite_f(&sVarf_b7gV5hyy, VIf(Bf10));
    __hv_varwrite_f(&sVarf_yPkzdcTI, VIf(Bf2));
    __hv_varwrite_f(&sVarf_cGZA91Tj, VIf(Bf9));
    __hv_varwrite_f(&sVarf_O78fgHGi, VIf(Bf11));
    __hv_varread_f(&sVarf_qMGfJFv2, VOf(Bf11));
    __hv_varread_f(&sVarf_Ov8qt39V, VOf(Bf9));
    __hv_varread_f(&sVarf_b7gV5hyy, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_yPkzdcTI, VOf(Bf2));
    __hv_varread_f(&sVarf_cGZA91Tj, VOf(Bf11));
    __hv_varread_f(&sVarf_O78fgHGi, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
